# DocArray

<p align="center">
<b>The universal data type for neural search</b>
</p>

<p align=center>
<a href="https://pypi.org/project/jina/"><img src="https://github.com/jina-ai/jina/blob/master/.github/badges/python-badge.svg?raw=true" alt="Python 3.7 3.8 3.9" title="Jina supports Python 3.7 and above"></a>
<a href="https://pypi.org/project/jina/"><img src="https://img.shields.io/pypi/v/docarray?color=%23099cec&amp;label=PyPI&amp;logo=pypi&amp;logoColor=white" alt="PyPI"></a>
</p>



## Install

```bash
pip install -U docarray
```

Jina already contains the latest `docarray`. If you have installed `jina`, then there is no need to install `docarray` again. 


## [Documentation](https://docs.jina.ai/fundamentals/document/)
